@@ -11,7 +11,7 @@
 #
 #
 # IDENTIFICATION
-#    $Header: /usr/local/cvsroot/postgres95/src/bin/destroydb/destroydb.sh,v 1.3 1996/07/27 02:19:12 scrappy Exp $
+#    $Header: /usr/local/cvsroot/postgres95/src/bin/destroydb/destroydb.sh,v 1.3.2.1 1996/09/21 06:18:33 scrappy Exp $
 #
 #-------------------------------------------------------------------------
 
@@ -23,7 +23,7 @@
 #       PGDATA, PGHOST, and PGPORT
 #
 # ----------------
-[ -z "$PGPORT" ] && PGPORT=5432
+[ -z "$PGPORT" ] && PGPORT=_fUnKy_POSTPORT_sTuFf_
 [ -z "$PGHOST" ] && PGHOST=localhost
 BINDIR=_fUnKy_BINDIR_sTuFf_
 PATH=$BINDIR:$PATH
